@@ -9,7 +9,7 @@ use DynaLoader();
 use Carp ();
 @ISA = qw(DynaLoader);
 
-$VERSION = '4.003';
+$VERSION = '4.004';
 
 bootstrap DBD::mysql $VERSION;
 
@@ -545,7 +545,7 @@ sub primary_key_info {
     my $desc_sth = $dbh->prepare("SHOW KEYS FROM $table_id");
     my $desc = $dbh->selectall_arrayref($desc_sth, { Columns=>{} });
     my $ordinal_pos = 0;
-    foreach my $row (@$desc) {
+    foreach my $row (grep { $_->{key_name} eq 'PRIMARY'} @$desc) {
 	$col_info{ $row->{column_name} } = {
 	    TABLE_CAT   => $catalog,
 	    TABLE_SCHEM => $schema,
@@ -966,6 +966,12 @@ in the MySQL client library by default. If your DSN contains the option
 this option is *ineffective* if the server has also been configured to
 disallow LOCAL.)
 
+=item mysql_multi_statements
+
+As of MySQL 4.1, support for multiple statements seperated by a semicolon
+(;) may be enabled by using this option. Enabling this option may cause
+problems if server-side prepared statements are also enabled.
+
 =item Prepared statement support (server side prepare)
 
 As of 3.0002_1, server side prepare statements were on by default (if your
@@ -1347,8 +1353,11 @@ DBI::SQL_SMALLINT() or DBI::SQL_VARCHAR().
 Similar to mysql, but type names and not numbers are returned.
 Whenever possible, the ANSI SQL name is preferred.
 
-=back
+=item mysql_warning_count
 
+The number of warnings generated during execution of the SQL statement.
+
+=back
 
 =head1 TRANSACTION SUPPORT
 
